#!/bin/sh

## Set ethernet adapter parameters for low-latency realtime performance, disable IPv6

REX_DEV=""
REX_CPU=1
REX_PRI=95

for dev in $REX_DEV; do

  if [ ! -d /sys/class/net/${dev} ]; then
    echo "Error: Device ${dev} does not exist" 1>&2
    exit 1
  fi

  echo "Setting IRQ affinity (${REX_CPU}) and priority (${REX_PRI}) on ${dev}"

  ip link set ${dev} up
  echo 1 > /proc/sys/net/ipv6/conf/${dev}/disable_ipv6

  sleep 1

  ethtool -C ${dev} tx-usecs 0 rx-usecs 0 2>/dev/null
  ethtool -L ${dev} combined 1 2>/dev/null
  ethtool -K ${dev} gso off gro off 2>/dev/null

  for d in ${dev} ${dev}-rx-0 ${dev}-tx-0; do
    for irq in /proc/irq/*; do
      [ -d ${irq}/${d} ] || continue
      pid=$(grep -l ${irq##*/}- /proc/*/comm | sed -e s/[^0-9]//g)
      echo -n "  $d: irq ${irq##*/}"
      if [ -n "$pid" ]; then
        echo -n " pid ${pid} [$(cat /proc/${pid}/comm)]"
      fi
      echo
      echo ${REX_CPU} > ${irq}/smp_affinity_list
      if [ -n "$pid" ]; then
        chrt -fp ${REX_PRI} ${pid} || echo "Error: Failed setting priority of PID ${pid}" 1>&2
      fi
    done
  done

done
